wmflib - Generic Python library for common tasks in the WMF production infrastructure
-------------------------------------------------------------------------------------

Wmflib is a generic Python library containing various modules to interact with the production infrastructure at the
Wikimedia Foundation. It can be used in scripts or more complex applications to avoid re-inventing the wheel every
time. The goal of the library is also to offer code that does not need any special privilege to be run (as opposed
to other libraries like Spicerack for example).
